@@ -717,8 +717,9 @@ class DebianGenerator(BloomGenerator):
         peer_packages = [p.name for p in self.packages.values()]
 
         while not self._check_all_keys_are_valid(peer_packages, self.rosdistro):
-            error("Some of the dependencies for packages in this repository could not be resolved by rosdep.",
-                  exit=not self.interactive)
+            error("Some of the dependencies for packages in this repository could not be resolved by rosdep.")
+            if not self.interactive:
+                sys.exit(code.GENERATOR_NO_ROSDEP_KEY_FOR_DISTRO)
             error("You can try to address the issues which appear above and try again if you wish.")
             try:
                 if not maybe_continue(msg="Would you like to try again?"):
